summaryrefslogtreecommitdiffstats
path: root/kioslave/home/kio_home.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kioslave/home/kio_home.cpp')
-rw-r--r--kioslave/home/kio_home.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kioslave/home/kio_home.cpp b/kioslave/home/kio_home.cpp
index eb9acd15a..3f307f6fd 100644
--- a/kioslave/home/kio_home.cpp
+++ b/kioslave/home/kio_home.cpp
@@ -40,11 +40,11 @@ static const KCmdLineOptions options[] =
extern "C" {
int KDE_EXPORT kdemain( int argc, char **argv )
{
// KApplication is necessary to use other ioslaves
putenv(strdup("SESSION_MANAGER="));
TDECmdLineArgs::init(argc, argv, "kio_home", 0, 0, 0, 0);
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app( false, false );
+ TDEApplication app( false, false );
// We want to be anonymous even if we use DCOP
app.dcopClient()->attach();
@@ -40,11 +40,11 @@ static const KCmdLineOptions options[] =
int KDE_EXPORT kdemain( int argc, char **argv )
{
- // KApplication is necessary to use other ioslaves
+ // TDEApplication is necessary to use other ioslaves
putenv(strdup("SESSION_MANAGER="));
TDECmdLineArgs::init(argc, argv, "kio_home", 0, 0, 0, 0);